@@ -330,13 +330,33 @@ load_database <- function(rv,
               get("source_system_name") == db_name,
             get("restricting_date_var")
           ]
+          restricting_date_format <- rv$mdr[
+            get("key") == i &
+              get("source_system_name") == db_name,
+            get("restricting_date_format")
+          ]
+          if (DIZtools::is.empty(restricting_date_format)) {
+            restricting_date_format <- "%Y-%m-%d"
+          }
+
+          # fix datetime-formatting for oracle / kdb here
+          # TODO: check overlaps with https://github.com/miracum/dqa-dqastats/
+          # blob/91a749cf1232b86af3d499c60b3cbb06dfe68618/R/
+          # datetime_restrictions.R#L333
+          # --> maybe try to resolve them / add replace string there
           replace_string <- paste0(
             "AS r_intermediate WHERE r_intermediate.",
-            restricting_date_var, " BETWEEN '",
-            rv$restricting_date$start,
-            "' AND '",
-            rv$restricting_date$end,
-            "'"
+            restricting_date_var, " BETWEEN TO_TIMESTAMP('",
+            as.Date(
+              rv$restricting_date$start,
+              format = restricting_date_format
+            ),
+            "', 'YYYY-MM-DD') AND TO_TIMESTAMP('",
+            as.Date(
+              rv$restricting_date$end,
+              format = restricting_date_format
+            ),
+            " 23:59:59', 'YYYY-MM-DD HH24:MI:SS')"
           )
           sql <- gsub("AS r_intermediate", replace_string, sql_statements[[i]])
           msg <- paste0(msg, " (using a MODIFIED SUBSELECT)")
@@ -367,6 +387,11 @@ load_database <- function(rv,
         sql <- sql_statements[[i]]
       }
 
+      # replace not-allowed AS for aliasing r_interediate in case of oracle statements
+      if (db_type == "oracle") {
+        sql <- gsub("AS r_intermediate", "r_intermediate", sql)
+      }
+
       ## The `sql_extended` is the same like the normal `sql` but extened with
       ## additional information needed to run the SQL, e.g. the commands
       ## to create a view which the `sql` utilizes:
