@@ -157,7 +157,7 @@ generate_datamap <- function(results,
 
   if (nrow(data_names) < 1) {
     msg <- "No variables suitable for the data map found in the MDR"
-    DIZutils::feedback(msg, logjs = isFALSE(headless), findme = "02c0846290",
+    DIZtools::feedback(msg, logjs = isFALSE(headless), findme = "02c0846290",
              logfile_dir = rv$log$logfile_dir,
              headless = rv$headless)
     return(NULL)
